function [data] = neuromag_load_extra_data(fiffile, extra_info, session_no)
% load data from fiffile.
% [USAGE]
%    [data] = neuromag_load_meg_data(<fiffile>, <session_no>);
% [IN]
%          fiffile : fiffile(Raw file or Evoked file)
% session_no : data index in fiffile.
%                   % = -1 : continuous raw data
%                   % >= 0 : Evoked data index
% [OUT]
%    data : The data of one channel in each row, a single time sample in
%           each column. Units: SI units. fT/m for gradiometers, fT for
%           magnetometers, V for electric channels.
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)


%
% --- Previous check
%
if ~exist('fiffile', 'var')
    error('fiffile is a required parameter.');
end
if ~exist('session_no', 'var')
    error('session_no is a required parameter.');
end
if exist(fiffile, 'file') ~= 2
    error('fiffile:%s is not found.', fiffile);
end

%
% --- Main Procedure
%
if session_no < 0
    % load Continuous data
	% open
	rawdata('any',fiffile);
	
	% get info
	Nsample = rawdata('samples');
    Nch = length(extra_info.Channel_id);
    
	data = zeros(Nch, Nsample);
	b = [];
	status = 'ok';
	start = 1;
	Nread = 0;
	% read data
	while(1)
	    [b, status] = rawdata('next');
	    if ~strcmp(status, 'ok'), break; end
	    Ndata = size(b, 2);
	    data(:, start:start+Ndata-1) = b(extra_info.Channel_id,:);
	    fprintf('.',start+Ndata-1, Nsample);
	    start = start + Ndata;
	    Nread = Nread + 1;
	    if mod(Nread, 50) == 0
	        fprintf('\n');
	    end
	end
	fprintf('\nfinished. [%d/%d]\n',Nsample, Nsample);
	
	% close
	rawdata('close');
else
    % load Evoked data
    [Nsets, Comment] = loadfif(fiffile, 'sets');
    if session_no >= Nsets
        error('invalid fiffile data index were specified.');
    end
    
    data = loadfif(fiffile, session_no, 'any');
	% Select extra channel
	data = data(extra_info.Channel_id,:);
end
