function [bexp] = neuromag_load_meg_data(fiffile, index_in_fiffile)
% load data from fiffile.
% [USAGE]
%    [bexp] = neuromag_load_meg_data(<fiffile>, <index_in_fiffile>);
% [IN]
%          fiffile : fiffile(Raw file or Evoked file)
% index_in_fiffile : data index in fiffile.
%                   % = -1 : continuous raw data
%                   % >= 0 : Evoked data index
% [OUT]
%    bexp : The data of one channel in each row, a single time sample in
%           each column. Units: SI units. fT/m for gradiometers, fT for
%           magnetometers, V for electric channels.
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

%
% --- Previous check
%
if ~exist('fiffile', 'var')
    error('fiffile is a required parameter.');
end
if ~exist('index_in_fiffile', 'var')
    error('index_in_fiffile is a required parameter.');
end
if exist(fiffile, 'file') ~= 2
    error('fiffile:%s is not found.', fiffile);
end

%
% --- Main Procedure
%
if index_in_fiffile < 0
    % load Continuous data
    [bexp, sf, Nsample] = neuromag_load_rawdata(fiffile);
else
    % load Evoked data
    [Nsets, Comment] = loadfif(fiffile, 'sets');
    if index_in_fiffile >= Nsets
        error('invalid fiffile data index were specified.');
    end
    bexp = loadfif(fiffile, index_in_fiffile);
end
