function [bexp, sf, Nsample] = neuromag_load_rawdata(fiffile)
% load neuromag rawdata-fiffile.(continuous data)
% [USAGE]
%    [data] = neuromag_load_rawdata(<fiffile>);
% [IN]
%    fiffile : neuromag rawdata fiffile.
% [OUT]
%       bexp : The data of one channel in each row, a single time
%              sample in each column. [Nch x Nsample]
%              (Units: SI units. fT/m forgradiometers, 
%              fT for magnetometers, V for electric channels.)
%         sf : Sampling Frequency(Units:Hz) [double]
%    Nsample : The number of samples.  [double]
%
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

%
% --- Previous check
%
if ~exist('fiffile', 'var')
    error('fiffile is a required parameter.');
end
if exist(fiffile, 'file') ~= 2
    error('fiffile:%s is not found.', fiffile);
end

%
%
% --- Read Data
%

% open
rawdata(fiffile);

% get info
sf      = rawdata('sf');
Nsample = rawdata('samples');

megmodel('head', fiffile);
[channel] = chaninfo; % T:COIL==>HEAD
Nch = length(channel);

% read data
bexp = zeros(Nch, Nsample);
b = [];
status = 'ok';
start = 1;
Nread = 0;
while(1)
    [b, status] = rawdata('next');
    if ~strcmp(status, 'ok'), break; end
    Ndata = size(b, 2);
    bexp(:, start:start+Ndata-1) = b;
    fprintf('.',start+Ndata-1, Nsample);
    start = start + Ndata;
    Nread = Nread + 1;
    if mod(Nread, 50) == 0
        fprintf('\n');
    end
end
fprintf('\nfinished. [%d/%d]\n',Nsample, Nsample);

% close
rawdata('close');
